Module: Jekyll
- Defined in:
- lib/bibsonomy-jekyll.rb
Overview
Jekyll Tag to render posts from BibSonomy.
Usage: bibsonomy GROUPING NAME TAG1 TAG2 … TAGN COUNT %
where
GROUPING is either "user" or "group" and specifies the type of NAME
NAME is the name of the group or user
TAG1 ... TAGN are tags
COUNT is an integer, the number of posts to return
Changes: 2018-10-08 (rja)
-
added liquid expansion
2017-05-31 (rja)
-
added support for groups and multiple tags
Defined Under Namespace
Classes: BibSonomyPostList